==> exchange-mule4-maven-plugin-0.0.0-sources.jar: com/mulesoft/exchange/mavenfacade/PublicationMojo.java <==
package com.mulesoft.exchange.mavenfacade;

import org.apache.maven.execution.MavenSession;
import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.BuildPluginManager;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugins.annotations.Component;
import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.project.MavenProject;

@Mojo(name = "exchange-deploy")
public class PublicationMojo extends AbstractMojo {

    @Component
    private MavenProject mavenProject;

    @Component
    private MavenSession mavenSession;

    @Component
    private BuildPluginManager pluginManager;

    public void execute() throws MojoExecutionException {
        MavenPluginParameters mavenPluginParameters = new MavenPluginParameters(mavenProject, mavenSession, pluginManager, getLog());

        ExchangeEOFDeployer exchangeEOFDeployer = new ExchangeEOFDeployer(mavenPluginParameters);
        PublicationStatusProvider publicationStatusProvider = new PublicationStatusProvider(mavenPluginParameters);

        PublicationStatusChecker publicationStatusChecker = new PublicationStatusChecker(publicationStatusProvider, getLog());

        try {
            // Upload the exchange-eof.json
            exchangeEOFDeployer.deploy();
            // Check publication status
            publicationStatusChecker.checkStatus();

        } catch (Exception e) {
            throw new MojoExecutionException("Exchange publication failed", e);
        }

        getLog().info("Everything ok!");
    }
}

==> exchange-mule4-maven-plugin-0.0.3-sources.jar: com/mulesoft/exchange/mavenfacade/PublicationMojo.java <==
package com.mulesoft.exchange.mavenfacade;

import com.mulesoft.exchange.mavenfacade.utils.ExchangeUriChecker;
import org.apache.maven.artifact.repository.ArtifactRepository;
import org.apache.maven.execution.MavenSession;
import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.BuildPluginManager;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugins.annotations.Component;
import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.project.MavenProject;

@Mojo(name = "exchange-deploy")
public class PublicationMojo extends AbstractMojo {

    @Component
    private MavenProject mavenProject;

    @Component
    private MavenSession mavenSession;

    @Component
    private BuildPluginManager pluginManager;

    public void execute() throws MojoExecutionException {
        MavenPluginParameters mavenPluginParameters = new MavenPluginParameters(mavenProject, mavenSession, pluginManager, getLog());
        ArtifactRepository repository = mavenPluginParameters.getMavenProject().getDistributionManagementArtifactRepository();
        ExchangeUriChecker.validateMavenV3RunIdUri(repository.getUrl());

        ExchangeEOFDeployer exchangeEOFDeployer = new ExchangeEOFDeployer(mavenPluginParameters);
        PublicationStatusProvider publicationStatusProvider = new PublicationStatusProvider(mavenPluginParameters);

        PublicationStatusChecker publicationStatusChecker = new PublicationStatusChecker(publicationStatusProvider, getLog());

        try {
            // Upload the exchange-eof.json
            exchangeEOFDeployer.deploy();
            // Check publication status
            publicationStatusChecker.checkStatus();

        } catch (Exception e) {
            throw new MojoExecutionException("Exchange publication failed", e);
        }

        getLog().info("Everything ok!");
    }
}
